semantic_gen library
Classes
- AutoTag
- Requests that the generator create semantics wrappers for a widget class.
- AutoWrapWidgets
- Declares additional widget types that should receive automatically generated wrappers within the annotated library.
- SelectableTextTagged
- Placeholder wrapper for SelectableText widgets prior to code generation.
- TestId
- An annotation used to assign a deterministic semantics label to a widget.
- TextFieldTagged
- Placeholder wrapper for TextField widgets prior to code generation.
- TextFormFieldTagged
- Placeholder wrapper for TextFormField widgets prior to code generation.
- TextTagged
- Placeholder wrapper for Text widgets prior to code generation.
- WrapperTemplate
- A wrapper template to apply to a widget.